use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Alders'
CPAN
Core
DBI
DDL
Database
Dave
Eilam
Eilam's
Florian
Gregory
Inc
Kevin
MAXMIND
MAXMIND's
MaxMind
MaxMind's
Migrator
OVERRIDEABLE
Olaf
Oschwald
Oschwald's
PayPal
Phair
Ragwitz
Rolsky
Rolsky's
Storey
Test
Types
William
autarch
goschwald
lib
olaf
phair
rafl
sql
unapplied
username
wstorey
